@@ -7,7 +7,7 @@ import re
 from discord.ext import commands
 from typing import Any, Awaitable, Callable, Optional, Union
 from .help_command import HelpCommand
-from .cogs.meta import Meta
+from .cogs.meta import Meta, C
 from .utils import *
 from .database import *
 
@@ -19,7 +19,7 @@ class DiscordBot(commands.Bot):
 
     def __init__(
             self,
-            prefix: Optional[str] = ".",
+            prefix: Optional[Union[str, Callable[[commands.Bot, discord.Message], str]]] = ".",
             color: Optional[Union[discord.Color, tuple, str]] = discord.Color.dark_theme(),
             database: Optional[str] = "bot.db",
             members_intent: Optional[bool] = False,
@@ -36,8 +36,10 @@ class DiscordBot(commands.Bot):
 
         Attributes
         ----------
-        prefix : Optional str
-            The command prefix for the bot (defaults to ".")
+        prefix : Optional Union(str, Callable(commands.Bot, discord.Message)->str)
+            The command prefix for the bot. This may also be a callable function (or coroutine) taking the bot as the first
+            argument and the message context as the second argument, which returns the prefix string.
+            This defaults to "."
         color : Optional Union(discord.Color, tuple, str)
             The default embed color to use for sending Discord embeds (defaults to `discord.Color.dark_theme()`)
             This parameter could be a `discord.Color` object, a hexadecimal color code, or an RGB tuple. The color will always
@@ -252,7 +254,7 @@ class DiscordBot(commands.Bot):
         else:
             raise ValueError(f"Invalid status string \"{status}\"")
         
-    async def _send_emoji_prepended_embed(self, ctx: commands.Context, emoji: str, content: str):
+    async def _send_emoji_prepended_embed(self, ctx: discord.abc.Messageable, emoji: str, content: str, color: discord.Color):
         """Sends an embed with an emoji and space both prepended to the left of the desired content to send
 
         This is mostly here to avoid dupicate code
@@ -266,9 +268,11 @@ class DiscordBot(commands.Bot):
         content : str
             The content to send. `emoji` and a space automatically prepended
             and truncated into the embed description
+        color : discord.Color
+            The color to make the embed
         """
 
-        embed = get_base_embed(description=f"{emoji} {content}", color=discord.Color.green(), timestamp=discord.Embed.Empty)
+        embed = get_base_embed(description=f"{emoji} {content}", color=color, timestamp=discord.Embed.Empty)
         await ctx.send(embed=embed)
 
     async def send_success_embed(self, ctx: discord.abc.Messageable, content: str):
@@ -285,7 +289,7 @@ class DiscordBot(commands.Bot):
             and truncated into the embed description
         """
 
-        await self._send_emoji_prepended_embed(ctx, ":white_check_mark:", content)
+        await self._send_emoji_prepended_embed(ctx, ":white_check_mark:", content, discord.Color.green())
 
     async def send_fail_embed(self, ctx: discord.abc.Messageable, content: str):
         """Sends an embed with a x emoji and a space prepended to the rest of the content
@@ -301,7 +305,7 @@ class DiscordBot(commands.Bot):
             and truncated into the embed description
         """
 
-        await self._send_emoji_prepended_embed(ctx, ":x:", content)
+        await self._send_emoji_prepended_embed(ctx, ":x:", content, discord.Color.red())
     
     async def send_warn_embed(self, ctx: discord.abc.Messageable, content: str):
         """Sends an embed with a warning emoji and a space prepended to the rest of the content
@@ -317,7 +321,7 @@ class DiscordBot(commands.Bot):
             and truncated into the embed description
         """
 
-        await self._send_emoji_prepended_embed(ctx, ":warning:", content)
+        await self._send_emoji_prepended_embed(ctx, ":warning:", content, discord.Color.gold())
 
     @staticmethod
     async def _retrieve_entity(snowflake: int, func: Callable[[int], Any], coro: Awaitable[int]):
